pub struct NowError { /* private fields */ }Expand description
This module implements a custom error currently over the AWS Lambda runtime, which can be extended later to support more service providers.
Implementations